@@ -200,10 +200,11 @@ class Project(MicroappObject, ProjectArgParser, Manager, DataRegistry):
             else:
                 args = [a for a in tostr_iter(args)]
 
-            if not sys.stdin.isatty():
-                args.append(tostr(sys.stdin.read().strip()))
-
             project_args = [a for a in tostr_iter(project_args)]
+
+            if not sys.stdin.isatty():
+                project_args.append(tostr(sys.stdin.read().strip()))
+
             group_args = [a for a in tostr_iter(group_args)]
             app_args = [a for a in tostr_iter(app_args)]
             
@@ -432,7 +433,7 @@ class MicroappProject(Project):
     """Microapp default project"""
 
     _name_ = "microapp"
-    _version_ = "0.3.3"
+    _version_ = "0.3.5"
     _description_ = "A command-line portal to Microapp apps."
     _long_description_ = "A command-line portal to Microapp apps."
     _author_ = "Youngsung Kim"
